from .logger import log
from tortoise import Tortoise


class Database:
    DB_URL = "sqlite://settings/database/database.db"
    DB_MODEL = {"models": ["src.utils"]}

    @staticmethod
    async def db_connect() -> None:
        try:
            await Tortoise.init(db_url=Database.DB_URL, modules=Database.DB_MODEL)
            await Tortoise.generate_schemas()
            log.info("[Database] SqLite connected")

        except Exception as e:
            log.error(f"[Database] Failed to connect SqLite: {e}")

    @staticmethod
    async def disconnect_db() -> None:
        await Tortoise.close_connections()



from setuptools import setup, find_packages
from pathlib import Path

this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()
requires = [
    "setuptools==75.8.0",
    "tortoise-orm==0.24.0",
    "disnake==2.10.1",
    "aiofiles==23.2.1",
    "loguru==0.7.2",
]
urls = {
    "Repository": "https://github.com/cyrax-dev/crxsnake",
    "Discord": "https://discord.gg/EEp67FWQDP",
}

setup(
    name="crxsnake",
    version="1.4.5",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="CRX-DEV",
    author_email="cherniq66@gmail.com",
    url="https://discord.gg/EEp67FWQDP",
    license="MIT License",
    packages=find_packages(),
    install_requires=requires,
    project_urls=urls
)
